<?php

namespace Drupal\user_provisioning\ProviderSpecific\APIHandler;

/**
 * Interface for classes defined in UserAPIHandler.
 */
interface moAPIHandlerInterface {

  /**
   * Makes the api get request.
   *
   * @param $resource_id
   *   The id of user entity.
   *
   * @return mixed
   *   Returns response interface.
   */
  public function get(string $query);

  /**
   * Makes the api post request.
   *
   * @param array $body
   *   The api request body.
   *
   * @return mixed
   *   Returns response interface.
   */
  public function post(array $body);

  /**
   * Makes the api put request.
   *
   * @param array $body
   *   The api request body.
   *
   * @return mixed
   *   Returns response interface.
   */
  public function put(array $body);

  /**
   * Makes the api patch request.
   *
   * @param array $patch
   *   The api request body.
   *
   * @return mixed
   *   Returns response interface.
   */
  public function patch(array $patch);

  /**
   * Makes the api delete request.
   *
   * @param $resource_id
   *   The id of user entity.
   *
   * @return mixed
   *   Returns response interface.
   */
  public function delete($resource_id);

  /**
   * Makes the api request for deactivation.
   *
   * @param array $body
   *   The api request body.
   *
   * @return mixed
   *   Returns response interface.
   */
  public function deactivate(array $body);

}
