<?php

namespace Drupal\user_provisioning\ProviderSpecific\Factory;

use Drupal\user_provisioning\moUserProvisioningConstants;
use Drupal\user_provisioning\ProviderSpecific\APIHandler\UserAPIHandler\moUserAzureAPIHandler;
use Drupal\user_provisioning\ProviderSpecific\APIHandler\UserAPIHandler\moUserOktaAPIHandler;
use Drupal\user_provisioning\ProviderSpecific\APIHandler\UserAPIHandler\moUserSCIMAPIHandler;
use Drupal\user_provisioning\ProviderSpecific\Parsers\UserParser\moUserAzureParser;
use Drupal\user_provisioning\ProviderSpecific\Parsers\UserParser\moUserOktaParser;
use Drupal\user_provisioning\ProviderSpecific\Parsers\UserParser\moUserSCIMParser;
use Drupal\user_provisioning\ProviderSpecific\ResponseProcessor\UserResponseProcessor\moUserAzureResponseProcessor;
use Drupal\user_provisioning\ProviderSpecific\ResponseProcessor\UserResponseProcessor\moUserOktaResponseProcessor;
use Drupal\user_provisioning\ProviderSpecific\ResponseProcessor\UserResponseProcessor\moUserSCIMResponseProcessor;

/**
 * Class for handling resource depending on appname.
 */
class moUserFactory implements moResourceFactoryInterface {

  /**
   * The configured app name.
   *
   * @var string
   */
  private string $appname;

  /**
   * Constructs a new moUserFactory object.
   */
  public function __construct() {
    $app_name = \Drupal::config('user_provisioning.settings')->get('mo_user_provisioning_configured_application');
    if (empty($app_name)) {
      // FIXME uncomment the above line after saving the configured application name.
      $app_name = moUserProvisioningConstants::DEFAULT_APP;
    }
    $this->appname = $app_name;
  }

  /**
   * Picks API Handler for corresponding app name.
   */
  public function getAPIHandler() {
    if ($this->appname == moUserProvisioningConstants::DEFAULT_APP) {
      return new moUserSCIMAPIHandler();
    }
    elseif ($this->appname == moUserProvisioningConstants::AZURE_AD) {
      return new moUserAzureAPIHandler();
    }
    elseif ($this->appname == moUserProvisioningConstants::OKTA) {
      return new moUserOktaAPIHandler();
    }
  }

  /**
   * Picks parser for corresponding app name.
   * */
  public function getParser() {
    if ($this->appname == moUserProvisioningConstants::DEFAULT_APP) {
      return new moUserSCIMParser();
    }
    elseif ($this->appname == moUserProvisioningConstants::AZURE_AD) {
      return new moUserAzureParser();
    }
    elseif ($this->appname == moUserProvisioningConstants::OKTA) {
      return new moUserOktaParser();
    }
  }

  /**
   * Picks responseprocessor for corresponding app name.
   * */
  public function getResponseProcessor() {
    if ($this->appname == moUserProvisioningConstants::DEFAULT_APP) {
      return new moUserSCIMResponseProcessor();
    }
    elseif ($this->appname == moUserProvisioningConstants::AZURE_AD) {
      return new moUserAzureResponseProcessor();
    }
    elseif ($this->appname == moUserProvisioningConstants::OKTA) {
      return new moUserOktaResponseProcessor();
    }
  }

}
