<?php

namespace Drupal\user_provisioning\ProviderSpecific\Parsers;

use Drupal\Core\Entity\EntityInterface;

/**
 * Interface for classes defined UserParser.
 */
interface moResourceParserInterface {

  /**
   * Creates url to serach specific resource.
   *
   * @param string $resource_id
   *   The resource_id to serach at application.
   *
   * @return string
   *   Returns url to search specific resource
   */
  public function search($resource_id): string;

  /**
   * Reads user at application.
   *
   * @param string $resource_id
   *   The id to get resource.
   *
   * @return mixed
   *   Returns response of user entity getting specific entity at application.
   */
  public function get($resource_id);

  /**
   * Creates user at application.
   *
   * @param Drupal\Core\Entity\EntityInterface $entity
   *   The entity to delete.
   *
   * @return mixed
   *   Returns response of user entity creation at application.
   */
  public function post(EntityInterface $entity);

  /**
   * Updates user at application.
   *
   * @param array $resource
   *   The entity to delete.
   *
   * @return mixed
   *   Returns response of user entity update at application.
   */
  public function put(array $resource);

  /**
   * Updates user at application.
   *
   * @param array $resource
   *   The user entity to update.
   *
   * @return mixed
   *   Returns response of user entity update at application.
   */
  public function patch(array $resource);

  /**
   * Deletes user at application.
   *
   * @param array $resource
   *   The entity to delete.
   *
   * @return mixed
   *   Returns response of user entity deletion at application.
   */
  public function delete(array $resource);

  /**
   * Deactivates user at application.
   *
   * @param Drupal\Core\Entity\EntityInterface $entity
   *   The entity to deactivate.
   *
   * @return mixed
   *   Returns response of user entity deletion at application.
   */
  public function deactivate(EntityInterface $entity);

}
