<?php

namespace Drupal\user_provisioning\ProviderSpecific\ResponseProcessor\UserResponseProcessor;

use Drupal\Component\Serialization\Json;
use Drupal\user_provisioning\moUserProvisioningConstants;
use Drupal\user_provisioning\ProviderSpecific\ResponseProcessor\moResourceResponseProcessorInterface;
use Psr\Http\Message\ResponseInterface;

/**
 * Class for Processing response of crud operation on user entity at azure.
 */
class moUserAzureResponseProcessor implements moResourceResponseProcessorInterface {

  /**
   * Processes response for read request of user.
   *
   * @param Psr\Http\Message\ResponseInterface $response
   *   The response of user deactivation.
   *
   * @return array
   *   Returns Status code and the content of the response
   */
  public function get(ResponseInterface $response) {
    $status_code = $response->getStatusCode();
    $content = $response->getBody()->getContents();
    $content_val = Json::decode($content);
    $user = $content_val['value'];

    // Initializing as conflict is not determined.
    $conflict = moUserProvisioningConstants::AZURE_CONFLICT_UNDETERMINED;
    if ($status_code == 200) {
      if (empty($user)) {
        // No conflict exists if no matching entity is found.
        $conflict = moUserProvisioningConstants::AZURE_NO_CONFLICT;
      }
      else {
        // Setting as conflict since one or more entity at the configured application is matched with the requested query.
        $conflict = moUserProvisioningConstants::AZURE_CONFLICT;
      }
    }
    return [$status_code, $content, $conflict];
  }

  /**
   * Processes response of user creation.
   *
   * @param Psr\Http\Message\ResponseInterface $response
   *   The response of user creation.
   *
   * @return array
   *   Returns Status code and the content of the response
   */
  public function post(ResponseInterface $response) {
    $status_code = $response->getStatusCode();
    $content = $response->getBody()->getContents();
    return [$status_code, $content];
  }

  /**
   * Processes response of user update using patch rquest.
   *
   * @param Psr\Http\Message\ResponseInterface $response
   *   The response of user update.
   */
  public function patch(ResponseInterface $response) {
    // @todo Implement patch() method.
  }

  /**
   * Processes response of user update using put request.
   *
   * @param Psr\Http\Message\ResponseInterface $response
   *   The response of user update.
   */
  public function put(ResponseInterface $response) {
    // @todo Implement put() method.
  }

  /**
   * Processes response of user deletion.
   *
   * @param Psr\Http\Message\ResponseInterface $response
   *   The response of user deletion.
   */
  public function delete(ResponseInterface $response) {
    // @todo Implement delete() method.
  }

  /**
   * Processes response of user deactivation.
   *
   * @param Psr\Http\Message\ResponseInterface $response
   *   The response of user deactivation.
   */
  public function deactivate(ResponseInterface $response) {
    // @todo Implement deactivate() method.
  }

}
