<?php

namespace Drupal\user_provisioning\ProviderSpecific\ResponseProcessor\UserResponseProcessor;

use Drupal\user_provisioning\moUserProvisioningConstants;
use Drupal\user_provisioning\ProviderSpecific\ResponseProcessor\moResourceResponseProcessorInterface;
use Psr\Http\Message\ResponseInterface;

/**
 * Class for processing response of crud operations on user at configured application.
 */
class moUserSCIMResponseProcessor implements moResourceResponseProcessorInterface {

  /**
   * Processes response of user read at application.
   *
   * @param \Psr\Http\Message\ResponseInterface $response
   *   Response received after the API call.
   *
   * @return array
   *   Returns Status code and the content of the response
   */
  public function get(ResponseInterface $response): array {
    $status_code = $response->getStatusCode();
    $content = $response->getBody()->getContents();

    // Initializing as conflict is not determined.
    $conflict = moUserProvisioningConstants::SCIM_CONFLICT_UNDETERMINED;
    if ($status_code == 200) {
      $response_body = json_decode($content, TRUE);
      if (isset($response_body['totalResults'])) {
        if ($response_body['totalResults'] == 0) {

          // No conflict exists if no matching entity is found.
          $conflict = moUserProvisioningConstants::SCIM_NO_CONFLICT;
        }
        else {
          // Setting as conflict since one or more entity at the configured application is matched with the requested query.
          $content = moUserProvisioningConstants::SCIM_CONFLICT;
        }
      }
    }
    return [$status_code, $content, $conflict];
  }

  /**
   * Processes response of user creation.
   *
   * @param \Psr\Http\Message\ResponseInterface $response
   *   Response received after the API call.
   *
   * @return array
   *   Returns Status code and the content of the response
   */
  public function post(ResponseInterface $response): array {
    $status_code = $response->getStatusCode();
    $content = $response->getBody()->getContents();

    // @todo need to add the content and its details at the database to refer for future api calls.
    return [$status_code, $content];
  }

  /**
   * Processes response of user update using patch request.
   *
   * @param Psr\Http\Message\ResponseInterface $response
   *   The response of user update.
   */
  public function patch(ResponseInterface $response) {
    // @todo Implement patch() method.
  }

  /**
   * Processes response of user update using put request.
   *
   * @param Psr\Http\Message\ResponseInterface $response
   *   The response of user update.
   */
  public function put(ResponseInterface $response) {
    // @todo Implement put() method.
  }

  /**
   * Processes response of user deletion.
   *
   * @param Psr\Http\Message\ResponseInterface $response
   *   The response of user deletion.
   */
  public function delete(ResponseInterface $response) {
    // @todo Implement delete() method.
  }

  /**
   * Processes response of user deactivation.
   *
   * @param Psr\Http\Message\ResponseInterface $response
   *   The response of user deactivation.
   */
  public function deactivate(ResponseInterface $response) {
    // @todo Implement deactivate() method.
  }

}
