<?php

namespace Drupal\user_provisioning\ProviderSpecific\ResponseProcessor;

use Psr\Http\Message\ResponseInterface;

/**
 * Interface for classes defined in UserResponseProcessor.
 */
interface moResourceResponseProcessorInterface {

  /**
   * Processes response for read request of user.
   *
   * @param \Psr\Http\Message\ResponseInterface $response
   *   The response of user read request.
   *
   * @return mixed
   *   Returns Status code and the content of the response
   */
  public function get(ResponseInterface $response);

  /**
   * Processes response of user creation.
   *
   * @param \Psr\Http\Message\ResponseInterface $response
   *   The response of user creation.
   *
   * @return mixed
   *   Returns Status code and the content of the response
   */
  public function post(ResponseInterface $response);

  /**
   * Processes response of user update using patch request.
   *
   * @param \Psr\Http\Message\ResponseInterface $response
   *   The response of user update.
   *
   * @return mixed
   *   Returns Status code and the content of the response
   */
  public function patch(ResponseInterface $response);

  /**
   * Processes response of user update using put request.
   *
   * @param \Psr\Http\Message\ResponseInterface $response
   *   The response of user update.
   *
   * @return mixed
   *   Returns Status code and the content of the response
   */
  public function put(ResponseInterface $response);

  /**
   * Processes response of user deletion.
   *
   * @param \Psr\Http\Message\ResponseInterface $response
   *   The response of user deletion.
   *
   * @return mixed
   *   Returns Status code and the content of the response
   */
  public function delete(ResponseInterface $response);

  /**
   * Processes response of user deactivation.
   *
   * @param \Psr\Http\Message\ResponseInterface $response
   *   The response of user deletion.
   *
   * @return mixed
   *   Returns Status code and the content of the response
   */
  public function deactivate(ResponseInterface $response);

}
